=== modified file 'drizzled/index_hint.cc'
--- drizzled/index_hint.cc	2011-02-17 00:14:13 +0000
+++ drizzled/index_hint.cc	2011-07-05 13:16:34 +0000
@@ -33,8 +33,7 @@
 #include <drizzled/index_hint.h>
 #include <drizzled/sql_table.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 /*
  * Names of the index hints (for error messages). Keep in sync with

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2011-07-04 19:11:47 +0000
+++ drizzled/item.cc	2011-07-05 13:16:34 +0000
@@ -371,7 +371,7 @@
   if (name)
   {
     str->append(STRING_WITH_LEN(" AS "));
-    str->append_identifier(name, (uint32_t) strlen(name));
+    str->append_identifier(str_ref(name));
   }
 }
 

=== modified file 'drizzled/item/ident.cc'
--- drizzled/item/ident.cc	2011-07-05 11:15:32 +0000
+++ drizzled/item/ident.cc	2011-07-05 13:16:34 +0000
@@ -118,30 +118,27 @@
 
   if (!table_name || !field_name || !field_name[0])
   {
-    const char *nm= (field_name && field_name[0]) ? field_name : name ? name : "tmp_field";
-    str->append_identifier(nm, (uint32_t) strlen(nm));
+    str->append_identifier(str_ref((field_name && field_name[0]) ? field_name : name ? name : "tmp_field"));
     return;
   }
   if (db_name && db_name[0] && !alias_name_used)
   {
-    {
-      str->append_identifier(d_name.c_str(), d_name.length());
-      str->append('.');
-    }
-    str->append_identifier(t_name.c_str(), t_name.length());
-    str->append('.');
-    str->append_identifier(field_name, (uint32_t)strlen(field_name));
+    str->append_identifier(d_name);
+    str->append('.');
+    str->append_identifier(t_name);
+    str->append('.');
+    str->append_identifier(str_ref(field_name));
   }
   else
   {
     if (table_name[0])
     {
-      str->append_identifier(t_name.c_str(), t_name.length());
+      str->append_identifier(t_name);
       str->append('.');
-      str->append_identifier(field_name, (uint32_t) strlen(field_name));
+      str->append_identifier(str_ref(field_name));
     }
     else
-      str->append_identifier(field_name, (uint32_t) strlen(field_name));
+      str->append_identifier(str_ref(field_name));
   }
 }
 

=== modified file 'drizzled/item/ref.cc'
--- drizzled/item/ref.cc	2011-07-04 19:11:47 +0000
+++ drizzled/item/ref.cc	2011-07-05 13:16:34 +0000
@@ -365,7 +365,7 @@
     if ((*ref)->type() != Item::CACHE_ITEM &&
         !table_name && name && alias_name_used)
     {
-      str->append_identifier(name, (uint32_t) strlen(name));
+      str->append_identifier(str_ref(name));
     }
     else
       (*ref)->print(str);

=== modified file 'drizzled/sql_string.cc'
--- drizzled/sql_string.cc	2011-07-04 18:16:24 +0000
+++ drizzled/sql_string.cc	2011-07-05 13:16:34 +0000
@@ -676,8 +676,12 @@
   append(&quote_char, 1);
 }
 
-bool check_if_only_end_space(const charset_info_st * const cs, char *str,
-                             char *end)
+void String::append_identifier(str_ref v)
+{
+  append_identifier(v.data(), v.size());
+}
+
+bool check_if_only_end_space(const charset_info_st * const cs, char *str, char *end)
 {
   return str+ cs->cset->scan(cs, str, end, MY_SEQ_SPACES) == end;
 }

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2011-07-04 17:50:09 +0000
+++ drizzled/sql_string.h	2011-07-05 13:16:34 +0000
@@ -22,6 +22,7 @@
 /* This file is originally from the mysql distribution. Coded by monty */
 
 #include <drizzled/common.h>
+#include <drizzled/util/data_ref.h>
 
 #include <cassert>
 #include <cstdlib>
@@ -119,6 +120,7 @@
     return Ptr;
   }
   void append_identifier(const char *name, size_t length);
+  void append_identifier(str_ref);
 
   void set(String &str,size_t offset,size_t arg_length)
   {

=== modified file 'drizzled/table_list.cc'
--- drizzled/table_list.cc	2011-07-05 11:15:32 +0000
+++ drizzled/table_list.cc	2011-07-05 13:16:34 +0000
@@ -292,10 +292,9 @@
       if (alias && alias[0])
       {
         str->append(' ');
-
         string t_alias(alias);
         boost::to_lower(t_alias);
-        str->append_identifier(t_alias.c_str(), t_alias.length());
+        str->append_identifier(t_alias);
       }
     }
 
@@ -304,8 +303,8 @@
       List<Index_hint>::iterator it(index_hints->begin());
       while (Index_hint* hint= it++)
       {
-        str->append (STRING_WITH_LEN(" "));
-        hint->print (session, str);
+        str->append(STRING_WITH_LEN(" "));
+        hint->print(session, str);
       }
     }
   }

=== added file 'drizzled/util/data_ref.h'
--- drizzled/util/data_ref.h	1970-01-01 00:00:00 +0000
+++ drizzled/util/data_ref.h	2011-07-05 13:16:34 +0000
@@ -0,0 +1,103 @@
+/* Drizzle
+ * Copyright (C) 2011 Olaf van der Spek
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
+
+#pragma once
+
+#include <cstddef>
+#include <cstring>
+
+template <class T>
+class data_ref_basic
+{
+public:
+  data_ref_basic()
+  {
+  }
+
+  template <class U>
+  data_ref_basic(U& c)
+  {
+    if (c.empty())
+      clear();
+    else
+      assign(&*c.begin(), &*c.end());
+  }
+
+  data_ref_basic(const void* b, const void* e)
+  {
+    assign(b, e);
+  }
+
+  data_ref_basic(const void* b, size_t sz)
+  {
+    assign(b, sz);
+  }
+
+  explicit data_ref_basic(const char* b)
+  {
+    assign(b, strlen(b));
+  }
+
+  void clear()
+  {
+    begin_ = NULL;
+    end_ = NULL;
+  }
+
+  void assign(const void* b, const void* e)
+  {
+		begin_ = reinterpret_cast<T>(b);
+		end_ = reinterpret_cast<T>(e);
+  }
+
+  void assign(const void* b, size_t sz)
+  {
+		begin_ = reinterpret_cast<T>(b);
+		end_ = begin_ + sz;
+  }
+
+  T begin() const
+  {
+    return begin_;
+  }
+
+  T end() const
+  {
+    return end_;
+  }
+
+  T data() const
+  {
+    return begin();
+  }
+
+  size_t size() const
+  {
+    return end() - begin();
+  }
+
+  bool empty() const
+  {
+    return begin() == end();
+  }
+private:
+  T begin_;
+  T end_;
+};
+
+typedef data_ref_basic<const unsigned char*> data_ref;
+typedef data_ref_basic<const char*> str_ref;

=== modified file 'drizzled/util/include.am'
--- drizzled/util/include.am	2011-02-24 07:08:02 +0000
+++ drizzled/util/include.am	2011-07-05 13:16:34 +0000
@@ -1,15 +1,15 @@
 # Copyright (C) 2010 Brian Aker
 # Copyright (C) 2009 Sun Microsystems, Inc.
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 of the License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
@@ -19,6 +19,7 @@
 			      drizzled/util/string.h \
                               drizzled/util/backtrace.h \
                               drizzled/util/convert.h \
+			      drizzled/util/data_ref.h \
 			      drizzled/util/find_ptr.h \
                               drizzled/util/functors.h \
                               drizzled/util/gmtime.h \

